Module: PgSqlTriggersRakeDevApp
- Defined in:
- lib/pg_sql_triggers/rake_development_boot.rb
Overview
Minimal Rails app for running engine Rake tasks from the gem repo (see rakelib/).
Defined Under Namespace
Classes: Application
Minimal Rails app for running engine Rake tasks from the gem repo (see rakelib/).
Classes: Application